@@ -180,7 +180,7 @@ public:
         }
 
         if (path.startsWith(QLatin1String("addToAddressBook"))) {
-            auto job = new Akonadi::AddContactJob(a, nullptr);
+            auto job = new ContactEditor::AddContactJob(a, nullptr);
             job->start();
         } else if (path.startsWith(QLatin1String("updateToAddressBook"))) {
             auto job = new UpdateContactJob(a.emails().constFirst(), a, nullptr);
@@ -247,7 +247,7 @@ public:
     Q_REQUIRED_RESULT bool openVCard(const KContacts::Addressee &a, const QString &vCard) const
     {
         Q_UNUSED(vCard)
-        auto view = new Akonadi::ContactViewer(nullptr);
+        auto view = new ContactEditor::ContactViewer(nullptr);
         view->setRawContact(a);
         view->setMinimumSize(300, 400);
         view->show();
